==> OpenViewerFX-6.6.14-sources.jar: org/jpedal/external/AnnotationHandler.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2015 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * AnnotationHandler.java
 * ---------------
 */
package org.jpedal.external;

import org.jpedal.io.PdfObjectReader;

import java.util.Map;
import org.jpedal.PdfDecoderInt;

public interface AnnotationHandler {

    /**called when each page created*/
    void handleAnnotations(PdfDecoderInt decode_pdf, Map objs, int p);

    /**called when mouse moves so you can react to context*/
    void checkLinks(Map objs, boolean mouseClicked, PdfObjectReader pdfObjectReader, int x, int y, org.jpedal.gui.GUIFactory currentGUI, org.jpedal.examples.viewer.Values commonValues);

}

==> OpenViewerFX-7.9.26-sources.jar: org/jpedal/external/AnnotationHandler.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2017 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * AnnotationHandler.java
 * ---------------
 */
package org.jpedal.external;

import java.util.Map;
import org.jpedal.PdfDecoderInt;
import org.jpedal.io.PdfObjectReader;
import org.jpedal.objects.raw.FormObject;

public interface AnnotationHandler {

    /**called when each page created*/
    void handleAnnotations(PdfDecoderInt decode_pdf, Map<FormObject, String>  objs, int p);

    /**called when mouse moves so you can react to context*/
    void checkLinks(Map objs, boolean mouseClicked, PdfObjectReader pdfObjectReader, int x, int y, org.jpedal.gui.GUIFactory currentGUI, org.jpedal.examples.viewer.Values commonValues);

}
